@@ -25,6 +25,11 @@ sub add {
 		$attributes{y} = $file->page->y;
 		$attributes{h} = $attributes{h} || $file->page->remaining_height();
 		$attributes{w} = $attributes{w} || $file->page->width();
+		if ($attributes{y} + $attributes{h} > $file->page->h) {
+			$file->page->next();
+			$attributes{x} = $file->page->x;
+			$attributes{y} = $file->page->y;
+		}
 	}
 	$self->set_attributes(%attributes);
 	my $type = $self->_identify_type();
@@ -32,7 +37,8 @@ sub add {
 	my %points = $self->get_points();
 	my $photo = $file->page->current->gfx;
 	if ($attributes{align} && $attributes{align} eq 'center') {
-		$points{x} = ($file->page->w - $points{w}) / 2;
+		my $single = ($file->page->w - ($file->page->padding * (2 + ($file->page->columns - 1)))) / $file->page->columns;
+		$points{x} = (($file->page->padding + $single) * ($file->page->column - 1)) + $file->page->padding + (($single - $points{w}) / 2);
 	}
 	$photo->image(
 		$image,
