@@ -25,7 +25,7 @@ sub add {
 
 	if (!$attributes{x} && !$attributes{align}) {
 		$attributes{x} = $file->page->x;
-		$attributes{y} = $file->page->y;
+		$attributes{y} = $attributes{y} || $file->page->y;
 		$attributes{h} = $file->page->remaining_height();
 		$attributes{w} = $file->page->width();
 	}
@@ -54,23 +54,29 @@ sub add {
 	my $indent = $self->indent;
 	
 	my @paragraphs = split /\n/, $self->text;
-	
 	my $space = $text->advancewidth(" ");
 
-	my @words = split / /, shift @paragraphs;
+	my $next_line = shift @paragraphs;
+	my @words = split(/ /, $next_line);
+	push @words, $1 if $next_line !~ m/^\s+$/ && $next_line =~ m/(\s+)$/;
+	push @words, $next_line unless scalar @words;
 
 	if ($indent) {
 		unshift @words, map { " " } 0 .. $indent;
 	}
-
+	
 	while ($ypos - $pos{l} >= $max_height && @words) {
-		my $word = shift @words;
+		my $word = shift @words; 
+		$word =~ s/\t/         /g;		
 		my ($width, @line) = ($text->advancewidth($word), ());
-		while ($width <= $pos{w} && $word) {
-			$width += $space;
+		while ($width <= $pos{w} && defined $word) {
 			push @line, $word;
 			$word = shift @words;
-			$width += $text->advancewidth($word);
+			if (defined $word) {
+				$width += $space unless $word =~ m/^(\s+)$/;
+				$word =~ s/\t/        /g;		
+				$width += $text->advancewidth($word);
+			}
 		}
 		$self->end_w($xpos + $width);
 		if ($word) {
@@ -89,6 +95,7 @@ sub add {
 			$xpos = $xpos + ((($pos{w} - $width) / 2) -  ($width / 2));
 		} elsif ($align eq 'right') {
 			$xpos = $xpos + ($pos{w} - $width);
+			$self->end_w($xpos + $pos{w});
 		}
 
 		$text->translate($xpos, $ypos);
